get_stats: get_stats: apply a standard set of statistical tests to the...

Description Usage Arguments

View source: R/mfafunctions96.R

Description

get_stats: apply a standard set of statistical tests to the data

Usage

1
get_stats(x, remove_outliers = FALSE)

Arguments

con_list

A list of consumption values belonging to a single group for analysis. remove_outliers A logical variables specifying whether to remove outliers from the data via IQR.


jwalte5/mfa96 documentation built on April 10, 2021, 4:36 p.m.