import_plates: import_plates: generates a full readout of all plate reads in...

Description Usage Arguments Examples

View source: R/mfafunctions96.R

Description

import_plates: generates a full readout of all plate reads in an xml document. Calls parse_IDs and parse_time functions to reformat the xml attributes.

Usage

1
import_plates(imp_xml)

Arguments

imp_xml

An internal xml document imported via xml2::read_xml().

Examples

 1
 2
 3
 4
 5
 6
 7
 8
 9
10
imp_xml = xml2::read_xml(xml_doc_path)
all_reads = import_plates(imp_xml)
print(all_reads)

Output:
ID               Project  Line       Assay    ReadTime
HARD_0420_BLZR    HARD    0420       BLZR     2020-07-02 11:54:00
TIPS_8008_SPEC    TIPS    8008       SPEC     2020-07-03 08:49:00
TORK_TAPE_SPEC    TORK    TAPE       SPEC     2020-07-02 14:10:00
HARD_BAPE_SPEC    HARD    BAPE       SPEC     2020-07-03 10:53:00

jwalte5/mfa96 documentation built on April 10, 2021, 4:36 p.m.