Description Usage Arguments Examples
View source: R/mfafunctions96.R
read_plates: creates a 3 dimensional array containing the plate reads for each sample in a plate row, plate column, plate ID format
1 | read_plates(imp_xml, calc_duration, soln_index, layout_matrix, sample_ID)
|
imp_xml: |
An internal xml document imported via xml2::read_xml(). |
1 2 3 4 5 6 7 8 9 10 11 12 13 14 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.