View source: R/mfafunctions96.R
get_stats: apply a standard set of statistical tests to the data
1 |
con_list |
A list of consumption values belonging to a single group for analysis. remove_outliers A logical variables specifying whether to remove outliers from the data via IQR. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.