Description Usage Arguments Examples
View source: R/mfafunctions96.R
parse_IDs: converts a vector of sample IDS into a matrix of factors for each respective ID.
1 | parse_IDs(id, sep = "_")
|
id: |
A vector containing character strings of sample IDs with each factor separated by a character. sep The character separating factors within the sample ID. Default sep = "_". |
1 2 3 4 5 6 7 8 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.